@@ -27,6 +27,7 @@
 #include "Task/AbstractTask.hpp"
 #include "SmartTaskAdvance.hpp"
 #include "Util/DereferenceIterator.hpp"
+#include "Util/StaticString.hpp"
 
 #include <assert.h>
 #include <vector>
@@ -85,6 +86,8 @@ private:
   TaskDijkstraMin *dijkstra_min;
   TaskDijkstraMax *dijkstra_max;
 
+  StaticString<64> name;
+
 public:
   /**
    * Constructor.
@@ -645,6 +648,19 @@ public:
    */
   unsigned GetLastIntermediateAchieved() const;
 
+  gcc_pure
+  const StaticString<64> &GetName() const {
+    return name;
+  }
+
+  void SetName(const StaticString<64> &name_) {
+    name = name_;
+  }
+
+  void ClearName() {
+    name.clear();
+  }
+
 public:
   /* virtual methods from class TaskInterface */
   virtual unsigned TaskSize() const override {
