@@ -28,10 +28,8 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef XCSOAR_QUAD_TREE_HPP
-#define XCSOAR_QUAD_TREE_HPP
-
-#include "Util/NonCopyable.hpp"
+#ifndef QUAD_TREE_HPP
+#define QUAD_TREE_HPP
 
 #include <utility>
 #include <limits>
@@ -58,7 +56,7 @@
  */
 template<typename T, typename Accessor,
          typename Alloc = std::allocator<T> >
-class QuadTree : private NonCopyable {
+class QuadTree {
   struct AlwaysTrue {
     constexpr
     bool operator()(const T &value) const {
@@ -133,7 +131,7 @@ public:
   };
 
   /**
-   * An rectangle on the plane that is parallel to the X and Y axes.
+   * A rectangle on the plane that is parallel to the X and Y axes.
    */
   struct Rectangle {
     position_type left, top, right, bottom;
@@ -933,6 +931,8 @@ public:
     bounds.Clear();
   }
 
+  QuadTree(const QuadTree &) = delete;
+
   ~QuadTree() {
     /* this needs to be called manually, because we can't pass the
        allocator references to the (Quad)Bucket / Leaf destructors */
